@@ -1,8 +1,65 @@
-package Time::Duration::Object;
-use Time::Duration;
-
-use warnings;
 use strict;
+use warnings;
+package Time::Duration::Object;
+{
+  $Time::Duration::Object::VERSION = '0.301';
+}
+# ABSTRACT: Time::Duration, but an object
+
+use Time::Duration 1.02;
+
+
+sub new {
+	my ($class, $duration) = @_;
+	return unless defined $duration;
+	bless \$duration => $class;
+}
+
+
+sub seconds {
+	return ${(shift)};
+}
+
+
+{
+  ## no critic (ProhibitNoStrict ProhibitNoWarnings)
+  no strict 'refs';
+  no warnings 'redefine';
+  my @methods = map { $_, "$_\_exact" } qw(duration ago from_now later earlier);
+  for (@methods) {
+    my $method = \&{"Time::Duration::$_"};
+    *{$_} = sub {
+      unshift @_, ${(shift)};
+      my $result = &$method(@_);
+      bless \$result => 'Time::Duration::_Result';
+    }
+  }
+}
+
+package Time::Duration::_Result;
+{
+  $Time::Duration::_Result::VERSION = '0.301';
+}
+
+
+sub as_string { ${ $_[0] } }
+
+
+sub concise {
+	my $self = shift;
+	Time::Duration::concise(${$self});
+}
+
+use overload
+	'""' => 'as_string',
+	fallback => 1;
+
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
@@ -10,11 +67,7 @@ Time::Duration::Object - Time::Duration, but an object
 
 =head1 VERSION
 
-version 0.300
-
-=cut
-
-our $VERSION = '0.300';
+version 0.301
 
 =head1 SYNOPSIS
 
@@ -35,25 +88,11 @@ good thing.
 
 This returns a new Time::Duration::Object for the given number of seconds.
 
-=cut
-
-sub new {
-	my ($class, $duration) = @_;
-	return unless defined $duration;
-	bless \$duration => $class;
-}
-
 =head2 C< seconds >
 
 This returns the number of seconds in the duration (i.e., the argument you
 passed to your call to C<new>.)
 
-=cut
-
-sub seconds {
-	return ${(shift)};
-}
-
 =head2 C<duration>
 
 =head2 C<duration_exact>
@@ -76,25 +115,6 @@ sub seconds {
 
 These methods all perform the function of the same name from Time::Duration.
 
-=cut
-
-{
-  ## no critic (ProhibitNoStrict ProhibitNoWarnings)
-  no strict 'refs';
-  no warnings 'redefine';
-  my @methods = map { $_, "$_\_exact" } qw(duration ago from_now later earlier);
-  for (@methods) {
-    my $method = \&{"Time::Duration::$_"};
-    *{$_} = sub {
-      unshift @_, ${(shift)};
-      my $result = &$method(@_);
-      bless \$result => 'Time::Duration::_Result';
-    }
-  }
-}
-
-package Time::Duration::_Result;
-
 =head2 as_string
 
 Time::Duration::Object methods don't return strings, they return an object that
@@ -104,10 +124,6 @@ concatenating an empty string, you can call C<as_string> instead.
  my $duration = Time::Duration::Object->new(8000);
  print $duration->ago->as_string; # 2 hours and 13 minutes ago
 
-=cut
-
-sub as_string { ${ $_[0] } }
-
 =head2 concise
 
 This method can be called on the result of the above methods, trimming down the
@@ -117,17 +133,6 @@ ouput.  For example:
  print $duration->ago; # 2 hours and 13 minutes ago
  print $duration->ago->concise # 2hr13m ago
 
-=cut
-
-sub concise {
-	my $self = shift;
-	Time::Duration::concise(${$self});
-}
-
-use overload
-	'""' => 'as_string',
-	fallback => 1;
-
 =head1 SEE ALSO
 
 Obviously, this module would be useless without Sean Burke's super-useful
@@ -136,22 +141,13 @@ that module...
 
 =head1 AUTHOR
 
-Ricardo Signes, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-time-duration-object@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004-2006 Ricardo Signes, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
