@@ -1,49 +1,16 @@
-package Time::Duration::Object::Infinite;
-
-use warnings;
 use strict;
+use warnings;
+package Time::Duration::Object::Infinite;
+{
+  $Time::Duration::Object::Infinite::VERSION = '0.301';
+}
+# ABSTRACT: Time::Duration::Object, but infinite
 
 sub isa {
   return 1 if $_[1] eq 'Time::Duration::Object';
   return $_[0]->UNIVERSAL::isa($_[1]);
 }
 
-=head1 NAME
-
-Time::Duration::Object::Infinite - Time::Duration::Object, but infinite
-
-=head1 VERSION
-
-version 0.300
-
-=cut
-
-our $VERSION = '0.300';
-
-=head1 SYNOPSIS
-
- use Time::Duration::Object::Infinite;
-
- my $duration = Time::Duration::Object::Infinite->new_future;
-
- # It will happen forever from now.
- print "It will happen ", $duration->from_now;
-
-=head1 DESCRIPTION
-
-This is a class for Time::Duration::Object-like objects representing infinite
-durations.
-
-=head1 METHODS
-
-=head2 C< new >
-
-=head2 C< new_positive >
-
-These methods return a new Time::Duration::Object::Infinite for a positive
-duration.
-
-=cut
 
 sub new_positive {
 	my ($class) = @_;
@@ -53,11 +20,6 @@ sub new_positive {
 
 sub new { shift->new_positive }
 
-=head2 C< new_negative >
-
-This returns a new Time::Duration::Object::Infinite for a negative duration.
-
-=cut
 
 sub new_negative {
 	my ($class) = @_;
@@ -67,25 +29,12 @@ sub new_negative {
 
 sub _is_pos { ${$_[0]} == -1 }
 
-=head2 C< seconds >
-
-This method returns either C<+inf> or C<-inf> using Math::BigInt.  (I don't
-recommend calling it.)
-
-=cut
 
 sub seconds {
   require Math::BigInt;
   return Math::BigInt->binf(shift->_is_pos ? '-' : ());
 }
 
-=head2 duration
-
-=head2 duration_exact
-
-These methods both return "forever."
-
-=cut
 
 sub duration { 'forever' }
 
@@ -105,6 +54,90 @@ BEGIN {
   $earlier_later = [ 'infinitely earlier', 'infinitely later' ];
 }
 
+
+sub ago       { $_[0]->_flop(1, $ago_from_now); }
+sub ago_exact { $_[0]->_flop(1, $ago_from_now); }
+
+
+sub from_now       { $_[0]->_flop(0, $ago_from_now); }
+sub from_now_exact { $_[0]->_flop(0, $ago_from_now); }
+
+
+sub later       { $_[0]->_flop(0, $earlier_later); }
+sub later_exact { $_[0]->_flop(0, $earlier_later); }
+
+
+sub earlier       { $_[0]->_flop(1, $earlier_later); }
+sub earlier_exact { $_[0]->_flop(1, $earlier_later); }
+
+package Time::Duration::_Result::_Infinite;
+{
+  $Time::Duration::_Result::_Infinite::VERSION = '0.301';
+}
+
+
+sub concise {
+	${ $_[0] }
+}
+
+sub as_string { ${ $_[0] } }
+
+use overload
+	'""' => 'as_string',
+	fallback => 1;
+
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Time::Duration::Object::Infinite - Time::Duration::Object, but infinite
+
+=head1 VERSION
+
+version 0.301
+
+=head1 SYNOPSIS
+
+ use Time::Duration::Object::Infinite;
+
+ my $duration = Time::Duration::Object::Infinite->new_future;
+
+ # It will happen forever from now.
+ print "It will happen ", $duration->from_now;
+
+=head1 DESCRIPTION
+
+This is a class for Time::Duration::Object-like objects representing infinite
+durations.
+
+=head1 METHODS
+
+=head2 new
+
+=head2 new_positive
+
+These methods return a new Time::Duration::Object::Infinite for a positive
+duration.
+
+=head2 new_negative
+
+This returns a new Time::Duration::Object::Infinite for a negative duration.
+
+=head2 new_seconds
+
+This method returns either C<+inf> or C<-inf> using Math::BigInt.  (I don't
+recommend calling it.)
+
+=head2 duration
+
+=head2 duration_exact
+
+These methods both return "forever."
+
 =head2 ago
 
 =head2 ago_exact
@@ -112,22 +145,12 @@ BEGIN {
 These methods return "forever ago" for positive durations and "forever from
 now" for negative durations.
 
-=cut
-
-sub ago       { $_[0]->_flop(1, $ago_from_now); }
-sub ago_exact { $_[0]->_flop(1, $ago_from_now); }
-
 =head2 from_now
 
 =head2 from_now_exact
 
 These methods do the opposite of the C<ago> methods.
 
-=cut
-
-sub from_now       { $_[0]->_flop(0, $ago_from_now); }
-sub from_now_exact { $_[0]->_flop(0, $ago_from_now); }
-
 =head2 later
 
 =head2 later_exact
@@ -135,24 +158,12 @@ sub from_now_exact { $_[0]->_flop(0, $ago_from_now); }
 These methods return "infinitely later" for positive durations and "infinitely
 earlier" for negative durations.
 
-=cut
+=head2 earlier
 
-sub later       { $_[0]->_flop(0, $earlier_later); }
-sub later_exact { $_[0]->_flop(0, $earlier_later); }
-
-=head2 C<earlier>
-
-=head2 C<earlier_exact>
+=head2 earlier_exact
 
 These methods do the opposite of the C<later> methods.
 
-=cut
-
-sub earlier       { $_[0]->_flop(1, $earlier_later); }
-sub earlier_exact { $_[0]->_flop(1, $earlier_later); }
-
-package Time::Duration::_Result::_Infinite;
-
 =head2 concise
 
 This method can be called on the result of the above methods, trimming down the
@@ -165,35 +176,15 @@ ouput.  For example:
 Doesn't look any shorter, does it?  No, it won't be.  These methods are here
 for compatibility with Time::Duration::Object's returns.
 
-=cut
-
-sub concise {
-	${ $_[0] }
-}
-
-sub as_string { ${ $_[0] } }
-
-use overload
-	'""' => 'as_string',
-	fallback => 1;
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2007 Ricardo Signes, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
